==> haskell-gauge-0.2.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.0
id: gauge-0.2.0-1DreTMaUhTv9BugFF6fY9
key: gauge-0.2.0-1DreTMaUhTv9BugFF6fY9
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time Paths_gauge
                Statistics.Distribution Statistics.Distribution.Normal
                Statistics.Function Statistics.Internal Statistics.Math.RootFinding
                Statistics.Matrix Statistics.Matrix.Algorithms
                Statistics.Matrix.Mutable Statistics.Matrix.Types
                Statistics.Quantile Statistics.Regression Statistics.Resampling
                Statistics.Resampling.Bootstrap Statistics.Sample
                Statistics.Sample.Histogram Statistics.Sample.Internal
                Statistics.Sample.KernelDensity Statistics.Transform
                Statistics.Types Statistics.Types.Internal
abi: a556ba652818c937ab088ef22376fd33
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/gauge-0.2.0
hs-libraries: HSgauge-0.2.0-1DreTMaUhTv9BugFF6fY9
depends:
    base-4.10.1.0 basement-0.0.4-7pJikASNmAFFwadsMZ0ihV deepseq-1.4.3.0
    mwc-random-0.13.6.0-3s7old0IIUJ6cNLUb7xtit
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4 process-1.6.1.0
    directory-1.3.0.2 math-functions-0.2.1.0-Ffg2SR9VoXB36fZMhQmMl1
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             basement-0.0.4-7pJikASNmAFFwadsMZ0ihV=71284c7f18b2b2dc2a5fd5dc4a6fd227
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             mwc-random-0.13.6.0-3s7old0IIUJ6cNLUb7xtit=741d941d62eb592b380bff475de4c419
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             math-functions-0.2.1.0-Ffg2SR9VoXB36fZMhQmMl1=a0979d22efcc2a646142971ceda8105e
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gauge-0.2.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.1
id: gauge-0.2.1-GuTgDQR49liEWxRB2lqp2i
key: gauge-0.2.1-GuTgDQR49liEWxRB2lqp2i
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
abi: 7606098163195885274d15bac9debc7c
exposed: True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time Paths_gauge
                Statistics.Distribution Statistics.Distribution.Normal
                Statistics.Function Statistics.Internal Statistics.Math.RootFinding
                Statistics.Matrix Statistics.Matrix.Algorithms
                Statistics.Matrix.Mutable Statistics.Matrix.Types
                Statistics.Quantile Statistics.Regression Statistics.Resampling
                Statistics.Resampling.Bootstrap Statistics.Sample
                Statistics.Sample.Histogram Statistics.Sample.Internal
                Statistics.Sample.KernelDensity Statistics.Transform
                Statistics.Types Statistics.Types.Internal System.Random.MWC
                Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
                Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum
import-dirs: /usr/lib/ghc-8.4.2/site-local/gauge-0.2.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/gauge-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/gauge-0.2.1
hs-libraries: HSgauge-0.2.1-GuTgDQR49liEWxRB2lqp2i
depends:
    base-4.11.1.0 basement-0.0.7-2rr6CUCXDXO23STP232Skz deepseq-1.4.3.0
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb process-1.6.3.0
    directory-1.3.1.5
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             basement-0.0.7-2rr6CUCXDXO23STP232Skz=b9469aed71b46ade42c22f303ffe0ad8
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
